@@ -37,6 +37,12 @@ class OperationClient:
                 bdev_name_list.append(name)
         return bdev_name_list
 
+    def examine_bdev(self, name):
+        params = {
+            "name": name,
+        }
+        self.spdk_client.call("bdev_examine", params)
+
     def create_pd_bdev(self, pd_bdev_name, pd_conf):
         params = {
             "name": pd_bdev_name,
